@@ -25,6 +25,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 // KDE
 #include <KGlobalSettings>
+#include <KLocalizedString>
 
 // Local
 #include "ui_generalconfigpage.h"
@@ -41,6 +42,7 @@ struct ConfigDialogPrivate
     InvisibleButtonGroup* mAlphaBackgroundModeGroup;
     InvisibleButtonGroup* mWheelBehaviorGroup;
     InvisibleButtonGroup* mAnimationMethodGroup;
+    InvisibleButtonGroup* mZoomModeGroup;
     InvisibleButtonGroup* mThumbnailBarOrientationGroup;
     Ui_GeneralConfigPage mGeneralConfigPage;
     Ui_ImageViewConfigPage mImageViewConfigPage;
@@ -61,8 +63,6 @@ ConfigDialog::ConfigDialog(QWidget* parent)
 , d(new ConfigDialogPrivate)
 {
     setFaceType(KPageDialog::List);
-    setButtons(KDialog::Ok | KDialog::Cancel | KDialog::Apply | KDialog::Default);
-    showButtonSeparator(true);
 
     QWidget* widget;
     KPageWidgetItem* pageItem;
@@ -70,7 +70,7 @@ ConfigDialog::ConfigDialog(QWidget* parent)
     // General
     widget = setupPage(d->mGeneralConfigPage);
     pageItem = addPage(widget, i18n("General"));
-    pageItem->setIcon(KIcon("gwenview"));
+    pageItem->setIcon(QIcon::fromTheme("gwenview"));
     connect(d->mGeneralConfigPage.kcfg_ViewBackgroundValue, SIGNAL(valueChanged(int)), SLOT(updateViewBackgroundFrame()));
 
     // Image View
@@ -92,18 +92,24 @@ ConfigDialog::ConfigDialog(QWidget* parent)
     d->mAnimationMethodGroup->addButton(d->mImageViewConfigPage.softwareAnimationRadioButton, int(DocumentView::SoftwareAnimation));
     d->mAnimationMethodGroup->addButton(d->mImageViewConfigPage.noAnimationRadioButton, int(DocumentView::NoAnimation));
 
+    d->mZoomModeGroup = new InvisibleButtonGroup(widget);
+    d->mZoomModeGroup->setObjectName(QLatin1String("kcfg_ZoomMode"));
+    d->mZoomModeGroup->addButton(d->mImageViewConfigPage.autofitZoomModeRadioButton, int(ZoomMode::Autofit));
+    d->mZoomModeGroup->addButton(d->mImageViewConfigPage.keepSameZoomModeRadioButton, int(ZoomMode::KeepSame));
+    d->mZoomModeGroup->addButton(d->mImageViewConfigPage.individualZoomModeRadioButton, int(ZoomMode::Individual));
+
     d->mThumbnailBarOrientationGroup = new InvisibleButtonGroup(widget);
     d->mThumbnailBarOrientationGroup->setObjectName(QLatin1String("kcfg_ThumbnailBarOrientation"));
     d->mThumbnailBarOrientationGroup->addButton(d->mImageViewConfigPage.horizontalRadioButton, int(Qt::Horizontal));
     d->mThumbnailBarOrientationGroup->addButton(d->mImageViewConfigPage.verticalRadioButton, int(Qt::Vertical));
 
     pageItem = addPage(widget, i18n("Image View"));
-    pageItem->setIcon(KIcon("view-preview"));
+    pageItem->setIcon(QIcon::fromTheme("view-preview"));
 
     // Advanced
     widget = setupPage(d->mAdvancedConfigPage);
     pageItem = addPage(widget, i18n("Advanced"));
-    pageItem->setIcon(KIcon("preferences-other"));
+    pageItem->setIcon(QIcon::fromTheme("preferences-other"));
     d->mAdvancedConfigPage.cacheHelpLabel->setFont(KGlobalSettings::smallestReadableFont());
 
     updateViewBackgroundFrame();
