@@ -18,16 +18,16 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
 // Local
-#include "semanticinfobackendtest.moc"
+#include "semanticinfobackendtest.h"
 
 // Qt
 #include <QSignalSpy>
 
 // KDE
-#include <KDebug>
+#include <QDebug>
 #include <KRandom>
 #include <KTemporaryFile>
-#include <qtest_kde.h>
+#include <qtest.h>
 
 // Local
 #include "testutils.h"
@@ -45,7 +45,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #endif
 #endif
 
-QTEST_KDEMAIN(Gwenview::SemanticInfoBackEndTest, GUI)
+QTEST_MAIN(Gwenview::SemanticInfoBackEndTest)
 
 namespace Gwenview
 {
@@ -53,18 +53,18 @@ namespace Gwenview
 SemanticInfoBackEndClient::SemanticInfoBackEndClient(AbstractSemanticInfoBackEnd* backEnd)
 : mBackEnd(backEnd)
 {
-    connect(backEnd, SIGNAL(semanticInfoRetrieved(KUrl,SemanticInfo)),
-            SLOT(slotSemanticInfoRetrieved(KUrl,SemanticInfo)));
+    connect(backEnd, SIGNAL(semanticInfoRetrieved(QUrl,SemanticInfo)),
+            SLOT(slotSemanticInfoRetrieved(QUrl,SemanticInfo)));
 }
 
-void SemanticInfoBackEndClient::slotSemanticInfoRetrieved(const KUrl& url, const SemanticInfo& semanticInfo)
+void SemanticInfoBackEndClient::slotSemanticInfoRetrieved(const QUrl &url, const SemanticInfo& semanticInfo)
 {
     mSemanticInfoForUrl[url] = semanticInfo;
 }
 
 void SemanticInfoBackEndTest::initTestCase()
 {
-    qRegisterMetaType<KUrl>("KUrl");
+    qRegisterMetaType<QUrl>("QUrl");
     qRegisterMetaType<QString>("SemanticInfoTag");
 }
 
@@ -92,11 +92,11 @@ void SemanticInfoBackEndTest::testRating()
     temp.setSuffix(".metadatabackendtest");
     QVERIFY(temp.open());
 
-    KUrl url;
+    QUrl url;
     url.setPath(temp.fileName());
 
     SemanticInfoBackEndClient client(mBackEnd);
-    QSignalSpy spy(mBackEnd, SIGNAL(semanticInfoRetrieved(KUrl,SemanticInfo)));
+    QSignalSpy spy(mBackEnd, SIGNAL(semanticInfoRetrieved(QUrl,SemanticInfo)));
     mBackEnd->retrieveSemanticInfo(url);
     QVERIFY(waitForSignal(spy));
 
